

loot = [
    {"type":"money", "name":"gold", "max":10},
    {"type":"money", "name":"silver", "max":20},
    {"type":"money", "name":"diamond", "max":3},
    {"type":"inventory", "name":"healing potion", "max":1},
    {"type":"inventory", "name":"dry bones", "max":1},
    {"type":"inventory", "name":"potion of energy", "max":1},
    {"type":"inventory", "name":"moldy apple", "max":1},
    {"type":"inventory", "name":"old potato", "max":1},
    {"type":"inventory", "name":"withered carrot", "max":1},
    {"type":"inventory", "name":"severed hand", "max":1},
    {"type":"inventory", "name":"severed finger", "max":1},
    {"type":"inventory", "name":"rotting flesh", "max":1},
    {"type":"inventory", "name":"moldy bread", "max":1},
    {"type":"inventory", "name":"squishy tomato", "max":1},
    {"type":"inventory", "name":"damp onion", "max":1},
    {"type":"inventory", "name":"onion", "max":1},
    {"type":"inventory", "name":"bread", "max":1},
    {"type":"inventory", "name":"apple", "max":1},
    {"type":"armor", "name":"", "max":1},
    {"type":"weapon", "name":"", "max":1},
]


foods = [
    {'name':'dry bones', 'health':2},
    {'name':'moldy apple', 'health':10},
    {'name':'old potato', 'health':10},
    {'name':'withered carrot', 'health':6},
    {'name':'severed hand', 'health':30},
    {'name':'severed finger', 'health':16},
    {'name':'rotting flesh', 'health':-6},
    {'name':'squishy tomato', 'health':8},
    {'name':'damp onion', 'health':6},
    {'name':'onion', 'health':12},
    {'name':'bread', 'health':20},
    {'name':'moldy bread', 'health':16},
    {'name':'apple', 'health':15},
]

valid_potions = ['potion of energy', 'healing potion']

valid_spells = ['sana ego', 'sana vulnera', 'sana omnis ego', 'confirma impetum', 'confirma defensio', 'noxa hostilis']